pub enum CoordinateConvention {
CenteredPositiveK,
}Variants
CenteredPositiveK
Spectra are stored with zero frequency at the array centre. Positive illumination k shifts the crop centre toward increasing array indices.